## [Intro Bite 03. Loop through a dictionary and pluralise a word](https://codechalleng.es/bites/103/)

Good luck and please share you code in the Bite forums upon completion.

For questions use [our Slack](https://pybites.slack.com/archives/C6BGDQQ3B) (no spoilers please).

Check out our full catalogue of Bites of Py [here](https://codechalleng.es/bites/catalogue).

Enjoy and keep calm and code in Python!